@@ -1,5 +1,5 @@
 # ===========================================================================
-# Crypt::GCrypt - version 1.1 - 10 Oct 2005
+# Crypt::GCrypt
 # 
 # Perl interface to the GNU Cryptographic library
 # 
@@ -15,7 +15,7 @@ package Crypt::GCrypt;
 use strict;
 use warnings;
 
-our $VERSION = '1.1';
+our $VERSION = '1.14';
 
 require XSLoader;
 XSLoader::load('Crypt::GCrypt', $VERSION);
@@ -31,7 +31,7 @@ Crypt::GCrypt - Perl interface to the GNU Cryptographic library
 
   use Crypt::GCrypt;
   
-  $cipher = GCrypt::Cipher->new(
+  $cipher = Crypt::GCrypt->new(
     type => 'cipher',
     algorithm => 'aes', 
     mode => 'cbc'
@@ -39,19 +39,18 @@ Crypt::GCrypt - Perl interface to the GNU Cryptographic library
   $cipher->start('encrypting');
   
   $cipher->setkey('my secret key');
-  
   $cipher->setiv('my init vector');
-  
+
   $ciphertext = $cipher->encrypt('plaintext');
   $ciphertext .= $cipher->finish;
-  
+
   $plaintext  = $cipher->decrypt($ciphertext);
 
 =head1 ABSTRACT
 
 Crypt::GCrypt provides an object interface to the C libgcrypt library. It
-currently supports symmetric encryption, while asymmetric encryption is 
-being worked on.
+currently supports symmetric encryption/decryption, while asymmetric 
+cryptography is being worked on.
 
 =head1 SYMMETRIC CRYPTOGRAPHY
 
@@ -60,12 +59,12 @@ being worked on.
 In order to encrypt/decrypt your data using a symmetric cipher you first have
 to build a Crypt::GCrypt object:
 
-  $cipher = GCrypt::Cipher->new(
+  $cipher = Crypt::GCrypt->new(
     type => 'cipher',
     algorithm => 'aes', 
     mode => 'cbc'
   );
-  
+
 The I<type> argument must be "cipher" and I<algorithm> is required too. See below
 for a description of available algorithms and other initialization parameters:
 
@@ -208,46 +207,46 @@ the cipher for encryption or decryption, resetting the internal state.
 
 =head2 setkey()
 
-   $cipher->setkey('my secret key')
+   $cipher->setkey('my secret key');
 
-Encryption and decryption operations will use I<KEY> until a different
-one is set. If I<KEY> is shorter than the cipher's keylen (see the
+Encryption and decryption operations will use this key until a different
+one is set. If your key is shorter than the cipher's keylen (see the
 C<keylen> method) it will be zero-padded, if it is longer it will be
 truncated.
 
 =head2 setiv()
 
-   $cipher->setiv('my iv')
+   $cipher->setiv('my iv');
 
-Set the initialisation vector to I<IV> for the next encrypt/decrypt operation.
+Set the initialisation vector for the next encrypt/decrypt operation.
 If I<IV> is missing a "standard" IV of all zero is used. The same IV is set in
 newly created cipher objects.
 
 =head2 encrypt()
 
-   $cipher->encrypt($plaintext)
+   $ciphertext = $cipher->encrypt($plaintext);
 
-This method encrypts I<PLAINTEXT> with $cipher, returning the
-corresponding ciphertext. Null byte padding is automatically appended
-if I<PLAINTEXT>'s length is not evenly divisible by $cipher's block
-size.
-
-=head2 decrypt()
-
-   $cipher->decrypt($ciphertext)
-
-The counterpart to encrypt, decrypt takes a I<CIPHERTEXT> and produces the
-original plaintext (given that the right key was used, of course).
+This method encrypts I<$plaintext> with I<$cipher>, returning the
+corresponding ciphertext. The output is buffered; this means that
+you'll only get multiples of $cipher's block size and that at the 
+end you'll have to call L</"finish()">.
 
 =head2 finish()
 
-   $cipher->finish;
+    $ciphertext .= $cipher->finish;
 
 The CBC algorithm must buffer data blocks internally until there are even 
 multiples of the encryption algorithm's blocksize (typically 8 or 16 bytes).
 After the last call to encrypt() you should call finish() to flush the internal
 buffer and return any leftover ciphertext. The internal buffer will be padded
-before encryption (see the I<padding> option above).
+before encryption (see the L</padding> option above).
+
+=head2 decrypt()
+
+   $plaintext = $cipher->decrypt($ciphertext);
+
+The counterpart to encrypt, decrypt takes a I<$ciphertext> and produces the
+original plaintext (given that the right key was used, of course).
 
 =head2 keylen()
 
@@ -289,7 +288,7 @@ the same terms as Perl itself.
 =head1 ACKNOWLEDGEMENTS
 
 This module was initially inspired by the GCrypt.pm bindings made by 
-Robert Bihlmeyer in 2002.
+Robert Bihlmeyer in 2002. Thanks to users who give feedback (see Changelog).
 
 =head1 DISCLAIMER
 
